summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/autoprojectpart.h
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/autoprojectpart.h')
-rw-r--r--buildtools/autotools/autoprojectpart.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/buildtools/autotools/autoprojectpart.h b/buildtools/autotools/autoprojectpart.h
index 08d83719..83066c3c 100644
--- a/buildtools/autotools/autoprojectpart.h
+++ b/buildtools/autotools/autoprojectpart.h
@@ -20,8 +20,8 @@
#include <tqmap.h>
#include <tqdatetime.h>
#include <tqdir.h>
-#include <tdevgenericfactory.h>
-#include "tdevbuildtool.h"
+#include <kdevgenericfactory.h>
+#include "kdevbuildtool.h"
class TQDomElement;
class TQStringList;
@@ -31,7 +31,7 @@ class TDESelectAction;
class TargetItem;
class ConfigWidgetProxy;
-class AutoProjectPart : public TDevBuildTool
+class AutoProjectPart : public KDevBuildTool
{
Q_OBJECT
@@ -41,7 +41,7 @@ public:
virtual ~AutoProjectPart();
/**
* Implementation of the TDevProject interface.
*/
virtual TQString projectDirectory() const;
virtual TQString projectName() const;
@@ -61,7 +61,7 @@ public:
virtual Options options() const;
/**
* Implementation of the TDevPlugin interface.
*/
virtual void restorePartialProjectSession ( const TQDomElement* el );
virtual void savePartialProjectSession ( TQDomElement* el );
@@ -85,7 +85,7 @@ public:
protected:
/**
* Reimplemented from TDevProject. These methods are only
* for use by the application core.
*/
virtual void openProject( const TQString &dirName, const TQString &projectName );
@@ -151,7 +151,7 @@ private:
bool queueInternalLibDependenciesBuild( TargetItem* titem, TQStringList& list );
};
-typedef TDevGenericFactory<AutoProjectPart> AutoProjectFactory;
+typedef KDevGenericFactory<AutoProjectPart> AutoProjectFactory;
#endif
// kate: indent-mode csands; tab-width 4;
@@ -41,7 +41,7 @@ public:
virtual ~AutoProjectPart();
/**
- * Implementation of the TDevProject interface.
+ * Implementation of the KDevProject interface.
*/
virtual TQString projectDirectory() const;
@@ -61,7 +61,7 @@ public:
virtual Options options() const;
/**
- * Implementation of the TDevPlugin interface.
+ * Implementation of the KDevPlugin interface.
*/
virtual void restorePartialProjectSession ( const TQDomElement* el );
@@ -85,7 +85,7 @@ public:
protected:
/**
- * Reimplemented from TDevProject. These methods are only
+ * Reimplemented from KDevProject. These methods are only
* for use by the application core.
*/